<div align="center">

# Self-Learning Entropic Population Annealing


</div>

## Description
This is a Python package that is designed for interpretable materials design in combinatorial search spaces based on entropic population annealing.

## Required Packages

- Python >= 3.6
- numpy
- scipy
- physbo
- modlamp

## Install

- From PyPI (recommended)

```bash
pip3 install slepa
```
- To update modlamp to the latest version, run the following:

```bash
pip install --upgrade slepa
```

- From source (for developers)
    1. Update pip (>= 19.0)

        ```bash
        pip3 install -U pip
        ```

    2. Download or clone the github repository

        ```
        git clone https://github.com/tsudalab/EntropicPopulationAnnealing
        ```

    3. Install via pip
        ``` bash
        pip3 install ./SLEPA
        ```


## Uninstall

```bash
pip3 uninstall slepa
```

## Usage

['examples/simple.py'](https://github.com/tsudalab/EntropicPopulationAnnealing) is a simple example.

## License

SLEPA package is distributed under GNU General Public License version 3 (GPL v3) or later.

### Copyright

© *2021- The University of Tokyo. All rights reserved.*